# Design Documents for Supported Features

Supported proposals describe extensions implemented and
released as fully supported features of the oneTBB library. A fully supported
feature has a high-quality implementation. If the proposal impacted the
public API of the library, it should appear in the oneTBB specification and
have supporting documentation in the oneTBB Reference as needed. A fully 
supported feature is regularly tested.

Proposals that appear in `rfcs/supported` may be retained indefinitely to
provide insight into the design of existing features.
